aboutsummaryrefslogtreecommitdiff
path: root/yarn
diff options
context:
space:
mode:
authorKay Ousterhout <kayousterhout@gmail.com>2013-10-30 17:07:24 -0700
committerKay Ousterhout <kayousterhout@gmail.com>2013-10-30 18:48:34 -0700
commit5e91495f5c718c837b5a5af2268f6faad00d357f (patch)
tree91cb0b036f4bf70748d695549ba8d11321101ff5 /yarn
parentdc9ce16f6b695295c24062a76fd10f574d278cac (diff)
downloadspark-5e91495f5c718c837b5a5af2268f6faad00d357f.tar.gz
spark-5e91495f5c718c837b5a5af2268f6faad00d357f.tar.bz2
spark-5e91495f5c718c837b5a5af2268f6faad00d357f.zip
Deduplicate Local and Cluster schedulers.
The code in LocalScheduler/LocalTaskSetManager was nearly identical to the code in ClusterScheduler/ClusterTaskSetManager. The redundancy made making updating the schedulers unnecessarily painful and error- prone. This commit combines the two into a single TaskScheduler/ TaskSetManager.
Diffstat (limited to 'yarn')
-rw-r--r--yarn/src/main/scala/org/apache/spark/scheduler/cluster/YarnClusterScheduler.scala10
1 files changed, 7 insertions, 3 deletions
diff --git a/yarn/src/main/scala/org/apache/spark/scheduler/cluster/YarnClusterScheduler.scala b/yarn/src/main/scala/org/apache/spark/scheduler/cluster/YarnClusterScheduler.scala
index 29b3f22e13..e873400680 100644
--- a/yarn/src/main/scala/org/apache/spark/scheduler/cluster/YarnClusterScheduler.scala
+++ b/yarn/src/main/scala/org/apache/spark/scheduler/cluster/YarnClusterScheduler.scala
@@ -17,16 +17,20 @@
package org.apache.spark.scheduler.cluster
+import org.apache.hadoop.conf.Configuration
+
import org.apache.spark._
import org.apache.spark.deploy.yarn.{ApplicationMaster, YarnAllocationHandler}
+import org.apache.spark.scheduler.TaskScheduler
import org.apache.spark.util.Utils
-import org.apache.hadoop.conf.Configuration
/**
*
* This is a simple extension to ClusterScheduler - to ensure that appropriate initialization of ApplicationMaster, etc is done
*/
-private[spark] class YarnClusterScheduler(sc: SparkContext, conf: Configuration) extends ClusterScheduler(sc) {
+private[spark] class YarnClusterScheduler(sc: SparkContext, conf: Configuration)
+ extends TaskScheduler(sc) {
logInfo("Created YarnClusterScheduler")
@@ -17,16 +17,20 @@
/**
*
- * This is a simple extension to ClusterScheduler - to ensure that appropriate initialization of ApplicationMaster, etc is done
+ * This is a simple extension to TaskScheduler - to ensure that appropriate initialization of
+ * ApplicationMaster, etc. is done
*/